SNOW: SNOW

Description Usage Arguments Value

View source: R/SNOW.R

Description

This routine was written to handle the various calls and data handling needed to solve the various components of the new VIC snow code for both the full_energy and water_balance models.

Usage

1
SNOW(InData, ...)

Arguments

InData

indata list, use SNOWIntercept(runMode = "VIEW") view the variables and theirs structures

...

other arguments

Value

use SNOW(runMode = "VIEW") view the outputs and theirs structure


MomentVon/EDHM documentation built on April 16, 2021, 10:22 p.m.